Functions to integrate different back-ends
m_backend_prompt(backend, additional)m_backend_submit(backend, x, prompt, preview = FALSE)
m_backend_submit does not return an object. m_backend_prompt
returns a list of functions that contain the base prompts.
An mall_session object
Additional text to insert to the base_prompt
The body of the text to be submitted to the LLM
The additional information to add to the submission
If TRUE, it will display the resulting R call of the
first text in x